summaryrefslogtreecommitdiffstats
path: root/ui/common/ui-system.c
diff options
context:
space:
mode:
Diffstat (limited to 'ui/common/ui-system.c')
-rw-r--r--ui/common/ui-system.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/common/ui-system.c b/ui/common/ui-system.c
index a828e2e..157c6db 100644
--- a/ui/common/ui-system.c
+++ b/ui/common/ui-system.c
@@ -142,10 +142,10 @@ static int kexec_reboot(int dry_run)
}
/**
* pb_run_kexec - Run kexec with the supplied boot options.
*/
-int pb_run_kexec(const struct pb_boot_data *bd, int dry_run)
+int pb_boot(const struct pb_boot_data *bd, int dry_run)
{
int result;
char *l_image = NULL;
@@ -142,10 +142,10 @@ static int kexec_reboot(int dry_run)
}
/**
- * pb_run_kexec - Run kexec with the supplied boot options.
+ * pb_boot - Run kexec with the supplied boot options.
*/
OpenPOWER on IntegriCloud